% This file is used to compute the values of Kp and Ki for the current and
% voltage regulators. It should be placed in the same folder as the
% Simulink file.


% PARAMETERS
CTRL_FREQUENCY = 20e3;      % Control is at 20kHz
CTRL_PERIOD = 1/CTRL_FREQUENCY;
Ts = 1.3*CTRL_PERIOD;

Lb = 1.5e-3;                % Inductor for the boost
Rb = 150e-3;                % Resistance of the inductor used for the boost
Cdc = 4*260e-6;             % DC link capacitor
Lg = 2.5e-3;                % Grid's inductors
Rg = 22e-3;                 % Resistance of grid's inductors

% BOOST CURRENT REGULATOR -------------------------------------------------
K1 = 1/Rb;
T1 = Lb/Rb;

Tn1 = T1;
Ti1 = 2*K1*Ts;

Kp1 = Tn1/Ti1;
Ki1 = 1/Ti1;

% BOOST CASCADED VOLTAGE REGULATOR ----------------------------------------
T2 = Cdc;
Ts2 = 13*CTRL_PERIOD;

Tn2 = 4*Ts2;
Ti2 = 8*Ts2^2/T2;

Kp2 = Tn2/Ti2;
Ki2 = 1/Ti2;

% INVERTER CURRENT REGULATOR ----------------------------------------------
Ts3 = Ts;

K3 = 1/Rg;
T3 = Lg/Rg;

Tn3 = T3;
Ti3 = 2*K3*Ts3;

Kp3 = Tn3/Ti3;
Ki3 = 1/Ti3;